@@ -1,6 +1,8 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2012 Daniel Mustieles <daniel.mustieles@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -50,7 +52,7 @@ static void apply_filter_cb (GtkButton *button, GdauiDataFilter *filter);
 
 struct _GdauiDataFilterPriv
 {
-	GdauiDataProxy   *data_widget;
+	GdauiDataProxy    *data_widget;
 	GdaDataProxy      *proxy;
 
 	GtkWidget         *filter_entry;
@@ -192,7 +194,7 @@ clear_filter_cb (GtkButton *button, GdauiDataFilter *filter)
 static void
 gdaui_data_filter_init (GdauiDataFilter * wid)
 {
-	GtkWidget *table, *label, *entry, *button, *bbox;
+	GtkWidget *grid, *label, *entry, *button, *bbox;
 	gchar *str;
 
 	wid->priv = g_new0 (GdauiDataFilterPriv, 1);
@@ -201,33 +203,31 @@ gdaui_data_filter_init (GdauiDataFilter * wid)
 
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (wid), GTK_ORIENTATION_VERTICAL);
 
-	table = gtk_table_new (2, 2, FALSE);
-	gtk_table_set_row_spacing (GTK_TABLE (table), 1, 10);
-	gtk_table_set_col_spacing (GTK_TABLE (table), 0, 5);
-	gtk_box_pack_start (GTK_BOX (wid), table, TRUE, TRUE, 0);
+	grid = gtk_grid_new ();
+	gtk_box_pack_start (GTK_BOX (wid), grid, TRUE, TRUE, 0);
 
 	label = gtk_label_new ("");
 	str = g_strdup_printf ("<b>%s</b>\n(<small>%s</small>):", _("Filter"), _("any valid SQL expression"));
 	gtk_label_set_markup (GTK_LABEL (label), str);
 	g_free (str);
 
-	gtk_widget_set_tooltip_markup (label, _("Columns can be referenced by thair name or more easily "
+	gtk_widget_set_tooltip_markup (label, _("Columns can be referenced by their name or more easily "
 						"using <b><tt>_&lt;column number&gt;</tt></b>. For example a valid "
 						"expression can be: <b><tt>_2 like 'doe%'</tt></b> "
 						"to filter rows where the 2nd column starts with <tt>doe</tt>."));
 
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_SHRINK, 0, 0, 0);
+	gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1, 1);
 	entry = gtk_entry_new ();
-	gtk_table_attach_defaults (GTK_TABLE (table), entry, 1, 2, 0, 1);
+	gtk_grid_attach (GTK_GRID (grid), entry, 1, 0, 1, 1);
 	g_signal_connect (G_OBJECT (entry), "activate",
 			  G_CALLBACK (apply_filter_cb), wid);
 
 	label = gtk_label_new ("");
 	wid->priv->notice = label;
-	gtk_table_attach (GTK_TABLE (table), label, 0, 2, 1, 2, GTK_FILL, 0, GTK_SHRINK, 5);
+	gtk_grid_attach (GTK_GRID (grid), label, 0, 1, 2, 1);
 
 	bbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
-	gtk_table_attach (GTK_TABLE (table), bbox, 0, 2, 2, 3, GTK_FILL | GTK_EXPAND, 0, GTK_SHRINK, 5);
+	gtk_grid_attach (GTK_GRID (grid), bbox, 0, 2, 2, 1);
 	button = gtk_button_new_with_label (_("Set filter"));
 	gtk_container_add (GTK_CONTAINER (bbox), button);
 	g_signal_connect (G_OBJECT (button), "clicked",
@@ -238,7 +238,7 @@ gdaui_data_filter_init (GdauiDataFilter * wid)
 	g_signal_connect (G_OBJECT (button), "clicked",
 			  G_CALLBACK (clear_filter_cb), wid);
 
-	gtk_widget_show_all (table);
+	gtk_widget_show_all (grid);
 	gtk_widget_hide (wid->priv->notice);
 
 	wid->priv->filter_entry = entry;
