@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2006 - 2013 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2007 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
@@ -28,15 +28,9 @@
 #include "handlers/gda-handler-time.h"
 #include "handlers/gda-handler-type.h"
 
-#if GLIB_CHECK_VERSION(2,31,7)
 static GRecMutex init_rmutex;
 #define MUTEX_LOCK() g_rec_mutex_lock(&init_rmutex)
 #define MUTEX_UNLOCK() g_rec_mutex_unlock(&init_rmutex)
-#else
-static GStaticRecMutex init_mutex = G_STATIC_REC_MUTEX_INIT;
-#define MUTEX_LOCK() g_static_rec_mutex_lock(&init_mutex)
-#define MUTEX_UNLOCK() g_static_rec_mutex_unlock(&init_mutex)
-#endif
 static void gda_data_handler_iface_init (gpointer g_class);
 
 GType
@@ -81,6 +75,15 @@ gda_data_handler_iface_init (G_GNUC_UNUSED gpointer g_class)
 	MUTEX_UNLOCK();
 }
 
+static gboolean
+_accepts_g_type (GdaDataHandler *dh, GType type)
+{
+	if (GDA_DATA_HANDLER_GET_IFACE (dh)->accepts_g_type)
+		return (GDA_DATA_HANDLER_GET_IFACE (dh)->accepts_g_type) (dh, type);
+	else
+		return FALSE;
+}
+
 /**
  * gda_data_handler_get_sql_from_value:
  * @dh: an object which implements the #GdaDataHandler interface
@@ -101,10 +104,12 @@ gchar *
 gda_data_handler_get_sql_from_value (GdaDataHandler *dh, const GValue *value)
 {
 	g_return_val_if_fail (dh && GDA_IS_DATA_HANDLER (dh), NULL);
-	
+
 	if (! value || gda_value_is_null (value))
 		return g_strdup ("NULL");
 
+	g_return_val_if_fail (_accepts_g_type (dh, G_VALUE_TYPE (value)), NULL);
+
 	/* Calling the real function with value != NULL and not of type GDA_TYPE_NULL */
 	if (GDA_DATA_HANDLER_GET_IFACE (dh)->get_sql_from_value)
 		return (GDA_DATA_HANDLER_GET_IFACE (dh)->get_sql_from_value) (dh, value);
@@ -121,6 +126,8 @@ gda_data_handler_get_sql_from_value (GdaDataHandler *dh, const GValue *value)
  * (in the user's locale, specially for the dates). If the value is 
  * NULL or is of type GDA_TYPE_NULL, the returned string is a copy of "" (empty string).
  *
+ * Note: the returned value will be in the current locale representation.
+ *
  * Returns: (transfer full): the new string, or %NULL if an error occurred
  */
 gchar *
@@ -131,6 +138,8 @@ gda_data_handler_get_str_from_value (GdaDataHandler *dh, const GValue *value)
 	if (! value || gda_value_is_null (value))
 		return g_strdup ("");
 
+	g_return_val_if_fail (_accepts_g_type (dh, G_VALUE_TYPE (value)), NULL);
+
 	/* Calling the real function with value != NULL and not of type GDA_TYPE_NULL */
 	if (GDA_DATA_HANDLER_GET_IFACE (dh)->get_str_from_value)
 		return (GDA_DATA_HANDLER_GET_IFACE (dh)->get_str_from_value) (dh, value);
@@ -158,7 +167,7 @@ GValue *
 gda_data_handler_get_value_from_sql (GdaDataHandler *dh, const gchar *sql, GType type)
 {
 	g_return_val_if_fail (dh && GDA_IS_DATA_HANDLER (dh), NULL);
-	g_return_val_if_fail (gda_data_handler_accepts_g_type (GDA_DATA_HANDLER (dh), type), NULL);
+	g_return_val_if_fail (_accepts_g_type (dh, type), NULL);
 
 	if (!sql)
 		return gda_value_new_null ();
@@ -184,13 +193,15 @@ gda_data_handler_get_value_from_sql (GdaDataHandler *dh, const gchar *sql, GType
  * if the @str string does not correspond to a valid string for the requested type, then
  * %NULL is returned.
  *
+ * Note: the @str string must be in the current locale representation
+ *
  * Returns: (transfer full): the new #GValue or %NULL on error
  */
 GValue *
 gda_data_handler_get_value_from_str (GdaDataHandler *dh, const gchar *str, GType type)
 {
 	g_return_val_if_fail (dh && GDA_IS_DATA_HANDLER (dh), NULL);
-	g_return_val_if_fail (gda_data_handler_accepts_g_type (GDA_DATA_HANDLER (dh), type), NULL);
+	g_return_val_if_fail (_accepts_g_type (dh, type), NULL);
 
 	if (!str)
 		return gda_value_new_null ();
@@ -222,7 +233,7 @@ GValue *
 gda_data_handler_get_sane_init_value (GdaDataHandler *dh, GType type)
 {
 	g_return_val_if_fail (dh && GDA_IS_DATA_HANDLER (dh), NULL);
-	g_return_val_if_fail (gda_data_handler_accepts_g_type (GDA_DATA_HANDLER (dh), type), NULL);
+	g_return_val_if_fail (_accepts_g_type (dh, type), NULL);
 
 	if (GDA_DATA_HANDLER_GET_IFACE (dh)->get_sane_init_value)
 		return (GDA_DATA_HANDLER_GET_IFACE (dh)->get_sane_init_value) (dh, type);
@@ -242,12 +253,8 @@ gda_data_handler_get_sane_init_value (GdaDataHandler *dh, GType type)
 gboolean
 gda_data_handler_accepts_g_type (GdaDataHandler *dh, GType type)
 {
-	g_return_val_if_fail (dh && GDA_IS_DATA_HANDLER (dh), FALSE);
-
-	if (GDA_DATA_HANDLER_GET_IFACE (dh)->accepts_g_type)
-		return (GDA_DATA_HANDLER_GET_IFACE (dh)->accepts_g_type) (dh, type);
-	
-	return FALSE;
+	g_return_val_if_fail (GDA_IS_DATA_HANDLER (dh), FALSE);
+	return _accepts_g_type (dh, type);
 }
 
 /**
@@ -298,11 +305,11 @@ gtype_equal (gconstpointer a, gconstpointer b)
 GdaDataHandler *
 gda_data_handler_get_default (GType for_type)
 {
-	static GStaticMutex mutex = G_STATIC_MUTEX_INIT;
+	static GMutex mutex;
 	static GHashTable *hash = NULL;
 	GdaDataHandler *dh;
 
-	g_static_mutex_lock (&mutex);
+	g_mutex_lock (&mutex);
 	if (!hash) {
 		hash = g_hash_table_new_full (gtype_hash, gtype_equal,
 					      NULL, (GDestroyNotify) g_object_unref);
@@ -322,6 +329,7 @@ gda_data_handler_get_default (GType for_type)
                 g_hash_table_insert (hash, (gpointer) G_TYPE_STRING, gda_handler_string_new ());
                 g_hash_table_insert (hash, (gpointer) GDA_TYPE_TIME, gda_handler_time_new ());
                 g_hash_table_insert (hash, (gpointer) GDA_TYPE_TIMESTAMP, gda_handler_time_new ());
+                g_hash_table_insert (hash, (gpointer) G_TYPE_DATE_TIME, gda_handler_time_new ());
                 g_hash_table_insert (hash, (gpointer) G_TYPE_CHAR, gda_handler_numerical_new ());
                 g_hash_table_insert (hash, (gpointer) G_TYPE_UCHAR, gda_handler_numerical_new ());
                 g_hash_table_insert (hash, (gpointer) G_TYPE_ULONG, gda_handler_numerical_new ());
@@ -329,7 +337,7 @@ gda_data_handler_get_default (GType for_type)
                 g_hash_table_insert (hash, (gpointer) G_TYPE_GTYPE, gda_handler_type_new ());
                 g_hash_table_insert (hash, (gpointer) G_TYPE_UINT, gda_handler_numerical_new ());
 	}
-	g_static_mutex_unlock (&mutex);
+	g_mutex_unlock (&mutex);
 
 	dh = g_hash_table_lookup (hash, (gpointer) for_type);
 	return dh;
