@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 - 2013 Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -35,6 +35,7 @@
 #include <virtual/libgda-virtual.h>
 #include <sql-parser/gda-sql-parser.h>
 #include <libgda/sql-parser/gda-sql-statement.h>
+#include <libgda/gda-debug-macros.h>
 
 typedef struct {
 	GValue *value;
@@ -121,7 +122,7 @@ static GdaDataModelAccessFlags gda_data_pivot_get_access_flags(GdaDataModel *mod
 static const GValue        *gda_data_pivot_get_value_at    (GdaDataModel *model, gint col, gint row, GError **error);
 
 static GObjectClass *parent_class = NULL;
-static GStaticMutex provider_mutex = G_STATIC_MUTEX_INIT;
+static GMutex provider_mutex;
 static GdaVirtualProvider *virtual_provider = NULL;
 
 /**
@@ -135,7 +136,7 @@ gda_data_pivot_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaDataPivotClass),
 			(GBaseInitFunc) NULL,
@@ -155,12 +156,12 @@ gda_data_pivot_get_type (void)
 			NULL
 		};
 
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0) {
 			type = g_type_register_static (G_TYPE_OBJECT, "GdaDataPivot", &info, 0);
 			g_type_add_interface_static (type, GDA_TYPE_DATA_MODEL, &data_model_info);
 		}
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -862,41 +863,21 @@ aggregate_handle_double (CellData *cdata, gdouble val)
 
 static gboolean
 aggregate_handle_char (CellData *cdata,
-#if GLIB_CHECK_VERSION(2,31,7)
 		       gint8 val
-#else
-		       gchar val
-#endif
 		       )
 {
 	if (cdata->data_value) {
-#if GLIB_CHECK_VERSION(2,31,7)
 		gint8 eval = 0;
-#else
-		gchar eval = 0;
-#endif
 		if (G_VALUE_TYPE (cdata->data_value) == G_TYPE_CHAR)
-#if GLIB_CHECK_VERSION(2,31,7)
 			eval = g_value_get_schar (cdata->data_value);
-#else
-			eval = g_value_get_char (cdata->data_value);
-#endif
 		switch (cdata->aggregate) {
 		case GDA_DATA_PIVOT_MIN:
 			if (eval > val)
-#if GLIB_CHECK_VERSION(2,31,7)
 				g_value_set_schar (cdata->data_value, val);
-#else
-				g_value_set_char (cdata->data_value, val);
-#endif
 			break;
 		case GDA_DATA_PIVOT_MAX:
 			if (eval < val)
-#if GLIB_CHECK_VERSION(2,31,7)
 				g_value_set_schar (cdata->data_value, val);
-#else
-				g_value_set_char (cdata->data_value, val);
-#endif
 			break;
 		case GDA_DATA_PIVOT_SUM: {
 			gint tmp;
@@ -906,11 +887,7 @@ aggregate_handle_char (CellData *cdata,
 					     GDA_DATA_PIVOT_ERROR, GDA_DATA_PIVOT_OVERFLOW_ERROR,
 					     "%s", _("Integer overflow"));
 			else
-#if GLIB_CHECK_VERSION(2,31,7)
 				g_value_set_schar (cdata->data_value, (gint8) tmp);
-#else
-				g_value_set_char (cdata->data_value, (gchar) tmp);
-#endif
 			break;
 		}
 		case GDA_DATA_PIVOT_AVG: {
@@ -936,11 +913,7 @@ aggregate_handle_char (CellData *cdata,
 		case GDA_DATA_PIVOT_MAX:
 		case GDA_DATA_PIVOT_SUM:
 			cdata->data_value = gda_value_new (G_TYPE_CHAR);
-#if GLIB_CHECK_VERSION(2,31,7)
 			g_value_set_schar (cdata->data_value, val);
-#else
-			g_value_set_char (cdata->data_value, val);
-#endif
 			break;
 		case GDA_DATA_PIVOT_AVG:
 			cdata->data_value = gda_value_new (G_TYPE_INT64);
@@ -1197,11 +1170,7 @@ aggregate_handle_new_value (CellData *cdata, const GValue *new_value)
 	else if (cdata->gtype == G_TYPE_DOUBLE)
 		return aggregate_handle_double (cdata, g_value_get_double (new_value));
 	else if (cdata->gtype == G_TYPE_CHAR)
-#if GLIB_CHECK_VERSION(2,31,7)
 		return aggregate_handle_char (cdata, g_value_get_schar (new_value));
-#else
-		return aggregate_handle_char (cdata, g_value_get_char (new_value));
-#endif
 	else if (cdata->gtype == G_TYPE_UCHAR)
 		return aggregate_handle_uchar (cdata, g_value_get_uchar (new_value));
 	else if (cdata->gtype == GDA_TYPE_SHORT)
@@ -2134,10 +2103,10 @@ create_vcnc (GdaDataPivot *pivot, GError **error)
 	if (pivot->priv->vcnc)
 		return TRUE;
 
-	g_static_mutex_lock (&provider_mutex);
+	g_mutex_lock (&provider_mutex);
 	if (!virtual_provider)
 		virtual_provider = gda_vprovider_data_model_new ();
-	g_static_mutex_unlock (&provider_mutex);
+	g_mutex_unlock (&provider_mutex);
 
 	vcnc = gda_virtual_connection_open (virtual_provider, &lerror);
 	if (! vcnc) {
