@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2009 Johannes Schmid <jhs@gnome.org>
- * Copyright (C) 2009 - 2010 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2009 - 2013 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
- * Copyright (C) 2011 Daniel Espinosa <esodan@gmail.com>
+ * Copyright (C) 2011 Daniel Espinosa <despinosa@src.gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -30,6 +30,7 @@
 #include <libgda/gda-statement.h>
 #include <libgda/gda-data-handler.h>
 #include <sql-parser/gda-sql-parser-enum-types.h>
+#include <libgda/gda-debug-macros.h>
 
 /*
  * Main static functions
@@ -82,7 +83,7 @@ gda_sql_builder_get_type (void) {
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaSqlBuilderClass),
 			(GBaseInitFunc) NULL,
@@ -96,10 +97,10 @@ gda_sql_builder_get_type (void) {
 			0
 		};
 
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (G_TYPE_OBJECT, "GdaSqlBuilder", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -551,11 +552,7 @@ create_typed_value (GType type, va_list *ap)
 	else if (type == GDA_TYPE_USHORT)
 		gda_value_set_ushort ((v = gda_value_new (GDA_TYPE_USHORT)), va_arg (*ap, guint));
 	else if (type == G_TYPE_CHAR)
-#if GLIB_CHECK_VERSION(2,31,7)
 		g_value_set_schar ((v = gda_value_new (G_TYPE_CHAR)), va_arg (*ap, gint));
-#else
-		g_value_set_char ((v = gda_value_new (G_TYPE_CHAR)), va_arg (*ap, gint));
-#endif
 	else if (type == G_TYPE_UCHAR)
 		g_value_set_uchar ((v = gda_value_new (G_TYPE_UCHAR)), va_arg (*ap, guint));
 	else if (type == G_TYPE_FLOAT)
@@ -823,7 +820,6 @@ gda_sql_builder_add_expr_value (GdaSqlBuilder *builder, G_GNUC_UNUSED GdaDataHan
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
 
-	gchar *str;
 	GdaSqlExpr *expr;
 	expr = gda_sql_expr_new (NULL);
 	if (value && (G_VALUE_TYPE (value) != GDA_TYPE_NULL)) {
@@ -1663,6 +1659,7 @@ gda_sql_builder_add_function (GdaSqlBuilder *builder, const gchar *func_name, ..
 		if (!part) {
 			expr->func->args_list = list;
 			gda_sql_expr_free (expr);
+			va_end (ap);
 			return 0;
 		}
 		list = g_slist_prepend (list, use_part (part, GDA_SQL_ANY_PART (expr->func)));
@@ -1684,9 +1681,9 @@ gda_sql_builder_add_function (GdaSqlBuilder *builder, const gchar *func_name, ..
  *
  * Returns: the ID of the new expression, or %0 if there was an error
  *
- * Since: 4.2
- *
  * Rename to: gda_sql_builder_add_function
+ *
+ * Since: 4.2
  */
 GdaSqlBuilderId
 gda_sql_builder_add_function_v (GdaSqlBuilder *builder, const gchar *func_name,
@@ -1908,6 +1905,7 @@ gda_sql_builder_add_case (GdaSqlBuilder *builder,
 	return add_part (builder, (GdaSqlAnyPart *) expr);
 
  cleanups:
+	va_end (ap);
 	gda_sql_expr_free (expr);
 	return 0;
 }
