@@ -2,7 +2,7 @@
  * Copyright (C) 2001 - 2003 Rodrigo Moya <rodrigo@gnome-db.org>
  * Copyright (C) 2002 - 2003 Gonzalo Paniagua Javier <gonzalo@gnome-db.org>
  * Copyright (C) 2002 Holger Thon <holger.thon@gnome-db.org>
- * Copyright (C) 2002 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2002 - 2013 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2002 Zbigniew Chyla <cyba@gnome.pl>
  * Copyright (C) 2003 Akira TAGOH <tagoh@gnome-db.org>
  * Copyright (C) 2003 Danilo Schoeneberg <dschoene@src.gnome.org>
@@ -10,7 +10,7 @@
  * Copyright (C) 2003 Philippe CHARLIER <p.charlier@chello.be>
  * Copyright (C) 2004 Andrew Hill <andru@src.gnome.org>
  * Copyright (C) 2004 Dani Baeyens <daniel.baeyens@hispalinux.es>
- * Copyright (C) 2004 - 2008 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2004 - 2011 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2004 Paisa  Seeluangsawat <paisa@users.sf.net>
  * Copyright (C) 2004 Szalai Ferenc <szferi@einstein.ki.iif.hu>
  * Copyright (C) 2007 Armin Burgmeier <armin@openismus.com>
@@ -19,6 +19,7 @@
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
+ * Copyright (C) 2011 - 2012 Daniel Espinosa <despinosa@src.gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -53,25 +54,23 @@
 #define bcmp(s1, s2, n) memcmp ((s1), (s2), (n))
 #endif
 
-extern gchar *gda_numeric_locale;
-
 #  ifdef GSEAL_ENABLE
 /**
  * GdaNumeric:
  * @number: a string representing a number
  * @precision: precision to use when @number is converted (not implemented jet)
- * @width: (not implemented jet)
+ * @width: not implemented jet
  *
  * Holds numbers represented as strings.
  *
  * This struct must be considered as opaque. Any access to its members must use its
  * accessors added since version 5.0.2.
  *
- * Set value func: gda_value_set_numeric
- * Get value func: gda_value_get_numeric
+ * Set value func: gda_value_set_numeric()
+ * Get value func: gda_value_get_numeric()
  */
 struct _GdaNumeric {
-	gchar*   number;
+	gchar*   number; /* stored in the "C" locale, never NULL */
 	glong    precision;
 	glong    width;
 	
@@ -171,11 +170,7 @@ set_from_string (GValue *value, const gchar *as_string)
 	else if (type == G_TYPE_CHAR) {
 		lvalue = strtol (as_string, endptr, 10);
 		if (*as_string!=0 && **endptr==0) {
-#if GLIB_CHECK_VERSION(2,31,7)
 			g_value_set_schar(value,(gint)lvalue);
-#else
-			g_value_set_char(value,(gchar)lvalue);
-#endif
 			retval = TRUE;
 		}
 	}
@@ -280,9 +275,7 @@ set_from_string (GValue *value, const gchar *as_string)
 			retval = TRUE;
 		}
 	}
-
-
-	if (!retval && g_value_type_transformable (G_TYPE_STRING, type)) {
+	else if (g_value_type_transformable (G_TYPE_STRING, type)) {
 		/* use the GLib type transformation function */
 		GValue *string;
 
@@ -414,7 +407,6 @@ gda_default_get_type (void)
 static void
 string_to_binary (const GValue *src, GValue *dest)
 {
-	/* FIXME: add more checks*/
 	GdaBinary *bin;
 	const gchar *as_string;
 
@@ -512,7 +504,6 @@ gda_binary_free (gpointer boxed)
 static void
 string_to_blob (const GValue *src, GValue *dest)
 {
-	/* FIXME: add more checks*/
 	GdaBlob *blob;
 	const gchar *as_string;
 
@@ -635,20 +626,19 @@ gda_blob_set_op (GdaBlob *blob, GdaBlobOp *op)
 static void
 geometric_point_to_string (const GValue *src, GValue *dest)
 {
-	gchar *str;
 	GdaGeometricPoint *point;
-
+	gchar *str;
 	g_return_if_fail (G_VALUE_HOLDS_STRING (dest) &&
 			  GDA_VALUE_HOLDS_GEOMETRIC_POINT (src));
 
 	point = (GdaGeometricPoint *) gda_value_get_geometric_point ((GValue *) src);
-
-	str = g_strdup_printf ("(%.*g,%.*g)",
-				  DBL_DIG,
-				  point->x,
-				  DBL_DIG,
-				  point->y);
-
+	if (point)
+		str = g_strdup_printf ("(%.*g,%.*g)", DBL_DIG, point->x,
+				       DBL_DIG, point->y);
+	else
+		str = g_strdup_printf ("(%.*g,%.*g)",
+				       DBL_DIG, 0.,
+				       DBL_DIG, 0.);
 	g_value_take_string (dest, str);
 }
 
@@ -656,7 +646,6 @@ geometric_point_to_string (const GValue *src, GValue *dest)
 static void
 string_to_geometricpoint (const GValue *src, GValue *dest)
 {
-	/* FIXME: add more checks*/
 	GdaGeometricPoint *point;
 	const gchar *as_string;
 
@@ -740,7 +729,7 @@ numeric_to_string (const GValue *src, GValue *dest)
 	if (numeric)
 		g_value_set_string (dest, numeric->number);
 	else
-		g_value_set_string (dest, "");
+		g_value_set_string (dest, "0.0");
 }
 
 static void
@@ -808,7 +797,7 @@ numeric_to_double (const GValue *src, GValue *dest)
 
 	numeric = gda_value_get_numeric (src);
 	if (numeric)
-		g_value_set_double (dest, g_strtod (numeric->number, NULL));
+		g_value_set_double (dest, gda_numeric_get_double (numeric));
 	else
 		g_value_set_double (dest, 0.0);
 }
@@ -823,7 +812,7 @@ numeric_to_float (const GValue *src, GValue *dest)
 
 	numeric = gda_value_get_numeric (src);
 	if (numeric)
-		g_value_set_float (dest, (float) g_strtod (numeric->number, NULL));
+		g_value_set_float (dest, (float) gda_numeric_get_double (numeric));
 	else
 		g_value_set_float (dest, 0.0);
 }
@@ -867,13 +856,19 @@ GdaNumeric*
 gda_numeric_copy (GdaNumeric *src)
 {
 	GdaNumeric *copy;
+	gchar *str;
 
 	g_return_val_if_fail (src, NULL);
 
 	copy = gda_numeric_new ();
-	gda_numeric_set_from_string (copy, gda_numeric_get_string (src));
+
+	str = gda_numeric_get_string (src);
+	gda_numeric_set_from_string (copy, str);
+	g_free (str);
+
 	gda_numeric_set_width (copy, gda_numeric_get_width (src));
 	gda_numeric_set_precision (copy, gda_numeric_get_precision (src));
+
 	return copy;
 }
 
@@ -892,6 +887,14 @@ gda_numeric_free (GdaNumeric *numeric)
 	g_free (numeric);
 }
 
+static gchar*
+gda_dtostr_dup (const double value)
+{
+	char buffer[G_ASCII_DTOSTR_BUF_SIZE];
+	g_ascii_dtostr (buffer, sizeof (buffer), value);
+	return g_strdup (buffer);
+}
+
 /**
  * gda_numeric_new:
  *
@@ -904,21 +907,18 @@ GdaNumeric*
 gda_numeric_new (void)
 {
 	GdaNumeric *n = g_new0 (GdaNumeric, 1);
-	setlocale (LC_NUMERIC, "C");
-	n->number = g_strdup_printf ("%lf", 0.0);
-	setlocale (LC_NUMERIC, gda_numeric_locale);
+	n->number = gda_dtostr_dup (0.0);
 	return n;
 }
 
 /**
  * gda_numeric_set_from_string:
  * @numeric: a #GdaNumeric
- * @str: a string representing a number
+ * @str: a string representing a number, in the C locale format
  *
- * Sets @numeric with a number represented by @str. By default converts @str to
- * #gdouble.
+ * Sets @numeric with a number represented by @str, in the C locale format (dot as a fraction separator).
  *
- * * Since: 5.0.2
+ * Since: 5.0.2
  */
 void
 gda_numeric_set_from_string (GdaNumeric *numeric, const gchar* str)
@@ -926,13 +926,15 @@ gda_numeric_set_from_string (GdaNumeric *numeric, const gchar* str)
 	g_return_if_fail (numeric);
 	g_return_if_fail (str);
 	g_free (numeric->number);
-	// FIXME: By default convert string to gdouble, for other number types we need to check string format
-	gdouble n = g_strtod (str, NULL);
-	setlocale (LC_NUMERIC, "C");
-	numeric->number = g_strdup_printf ("%lf", n);
-	setlocale (LC_NUMERIC, gda_numeric_locale);
-}
 
+	gdouble number;
+	gchar *endptr = NULL;
+	number = g_ascii_strtod (str, &endptr);
+	if (*endptr)
+		numeric->number = gda_dtostr_dup (number);
+	else
+		numeric->number = g_strdup (str);
+}
 
 /**
  * gda_numeric_set_double:
@@ -948,9 +950,7 @@ gda_numeric_set_double (GdaNumeric *numeric, gdouble number)
 {
 	g_return_if_fail (numeric);
 	g_free (numeric->number);
-	setlocale (LC_NUMERIC, "C");
-	numeric->number = g_strdup_printf ("%lf", number);
-	setlocale (LC_NUMERIC, gda_numeric_locale);
+	numeric->number = gda_dtostr_dup (number);
 }
 
 /**
@@ -961,13 +961,10 @@ gda_numeric_set_double (GdaNumeric *numeric, gdouble number)
  * Since: 5.0.2
  */
 gdouble
-gda_numeric_get_double (GdaNumeric *numeric)
+gda_numeric_get_double (const GdaNumeric *numeric)
 {
 	g_return_val_if_fail (numeric, 0.0);
-	if (numeric->number)
-		return atof (numeric->number);
-	else
-		return 0.0;
+	return g_ascii_strtod (numeric->number, NULL);
 }
 
 /**
@@ -993,10 +990,11 @@ gda_numeric_set_width (GdaNumeric *numeric, glong width)
  * Gets the width of a #GdaNumeric. (Not yet implemented).
  *
  * Returns: an integer with the width of a #GdaNumeric. (Not jet implemented).
+ *
  * Since: 5.0.2
  */
 glong
-gda_numeric_get_width (GdaNumeric *numeric)
+gda_numeric_get_width (const GdaNumeric *numeric)
 {
 	g_return_val_if_fail (numeric, 0.0);
 	return numeric->width;
@@ -1025,10 +1023,11 @@ gda_numeric_set_precision (GdaNumeric *numeric, glong precision)
  * Gets the precision of a #GdaNumeric.
  *
  * Returns: an integer with the precision of a #GdaNumeric.
+ *
  * Since: 5.0.2
  */
 glong
-gda_numeric_get_precision (GdaNumeric *numeric)
+gda_numeric_get_precision (const GdaNumeric *numeric)
 {
 	g_return_val_if_fail (numeric, -1);
 	return numeric->precision;
@@ -1037,16 +1036,19 @@ gda_numeric_get_precision (GdaNumeric *numeric)
  * gda_numeric_get_string:
  * @numeric: a #GdaNumeric
  *
- * Get the string representation of @numeric.
+ * Get the string representation of @numeric, in the C locale format (dot as a fraction separator).
  *
  * Returns: (transfer full) (allow-none): a new string representing the stored valued in @numeric
+ *
  * Since: 5.0.2
  */
 gchar*
-gda_numeric_get_string (GdaNumeric *numeric)
+gda_numeric_get_string (const GdaNumeric *numeric)
 {
-	g_return_val_if_fail (numeric, NULL);
-	return g_strdup (numeric->number);
+	if (numeric)
+		return g_strdup (numeric->number);
+	else
+		return NULL;
 }
 
 /*
@@ -1057,26 +1059,30 @@ static void
 time_to_string (const GValue *src, GValue *dest)
 {
 	GdaTime *gdatime;
-	GString *string;
 
 	g_return_if_fail (G_VALUE_HOLDS_STRING (dest) &&
 			  GDA_VALUE_HOLDS_TIME (src));
 
 	gdatime = (GdaTime *) gda_value_get_time ((GValue *) src);
 
-	string = g_string_new ("");
-	g_string_append_printf (string, "%02u:%02u:%02u",
-				gdatime->hour,
-				gdatime->minute,
-				gdatime->second);
-	if (gdatime->fraction != 0)
-		g_string_append_printf (string, ".%lu", gdatime->fraction);
+	if (gdatime) {
+		GString *string;
+		string = g_string_new ("");
+		g_string_append_printf (string, "%02u:%02u:%02u",
+					gdatime->hour,
+					gdatime->minute,
+					gdatime->second);
+		if (gdatime->fraction != 0)
+			g_string_append_printf (string, ".%lu", gdatime->fraction);
 
-	if (gdatime->timezone != GDA_TIMEZONE_INVALID)
-		g_string_append_printf (string, "%+02d", (int) gdatime->timezone / 3600);
+		if (gdatime->timezone != GDA_TIMEZONE_INVALID)
+			g_string_append_printf (string, "%+02d", (int) gdatime->timezone / 3600);
 
-	g_value_take_string (dest, string->str);
-	g_string_free (string, FALSE);
+		g_value_take_string (dest, string->str);
+		g_string_free (string, FALSE);
+	}
+	else
+		g_value_set_string (dest, "00:00:00");
 }
 
 /* Transform a String GValue to a GdaTime from a string like "12:30:15+01" */
@@ -1234,14 +1240,65 @@ gda_time_valid (const GdaTime *time)
 {
 	g_return_val_if_fail (time, FALSE);
 
-	if (time->hour > 24 ||
-	    time->minute > 59 ||
-	    time->second > 59)
+	if ((time->hour > 23) ||
+	    (time->minute > 59) ||
+	    (time->second > 59))
 		return FALSE;
-	else
-		return TRUE;
+	if ((time->fraction >= 1000000) ||
+	    (time->timezone <= -12 * 3600) ||
+	    (time->timezone >= 12 * 3600))
+		return FALSE;
+	return TRUE;
 }
 
+/**
+ * gda_time_change_timezone:
+ * @time: a valid #GdaTime
+ * @ntz: a new timezone to use, in seconds added to GMT
+ *
+ * Changes @time's timezone (for example to convert from GMT to another time zone).
+ * If @time's current timezone is unset (i.e. equal to %GDA_TIMEZONE_INVALID), then this function simply sets
+ * @time's timezone attribute; Otherwise, it adds or removes hours, minutes or seconds to reflect the time in the new timezone.
+ *
+ * Note: the resulting will always be a valid time.
+ *
+ * Since: 5.2
+ */
+void
+gda_time_change_timezone (GdaTime *time, glong ntz)
+{
+	g_return_if_fail (time);
+	g_return_if_fail (gda_time_valid (time));
+	g_return_if_fail ((ntz > - 12 * 3600) && (ntz < 12 * 3600));
+
+	if (time->timezone == ntz)
+		return;
+
+	if (time->timezone != GDA_TIMEZONE_INVALID) {
+		glong nsec;
+		nsec = time->hour * 3600 + time->minute * 60 + time->second - time->timezone + ntz;
+		if (nsec < 0)
+			nsec += 86400;
+		else if (nsec >= 86400)
+			nsec -= 86400;
+
+		/* hours */
+		gint n;
+		n = nsec / 3600;
+		time->hour = (gushort) n;
+
+		/* minutes */
+		nsec -= n * 3600;
+		n = nsec / 60;
+		time->minute = (gushort) n;
+
+		/* seconds */
+		nsec -= n * 60;
+		time->second = (gushort) nsec;
+	}
+
+	time->timezone = ntz;
+}
 
 /*
  * Register the GdaTimestamp type in the GType system
@@ -1250,14 +1307,12 @@ gda_time_valid (const GdaTime *time)
 static void
 string_to_timestamp (const GValue *src, GValue *dest)
 {
-	/* FIXME: add more checks*/
 	GdaTimestamp timestamp;
 
 	g_return_if_fail (G_VALUE_HOLDS_STRING (src) &&
 			  GDA_VALUE_HOLDS_TIMESTAMP (dest));
 
-	if (! gda_parse_iso8601_timestamp (&timestamp, g_value_get_string (src)))
-		g_warning ("Can't convert '%s' to a timestamp", g_value_get_string (src));
+	gda_parse_iso8601_timestamp (&timestamp, g_value_get_string (src));
 	gda_value_set_timestamp (dest, &timestamp);
 }
 
@@ -1265,28 +1320,31 @@ static void
 timestamp_to_string (const GValue *src, GValue *dest)
 {
 	GdaTimestamp *timestamp;
-	GString *string;
 
 	g_return_if_fail (G_VALUE_HOLDS_STRING (dest) &&
 			  GDA_VALUE_HOLDS_TIMESTAMP (src));
 
 	timestamp = (GdaTimestamp *) gda_value_get_timestamp ((GValue *) src);
-
-	string = g_string_new ("");
-	g_string_append_printf (string, "%04u-%02u-%02u %02u:%02u:%02u",
-				timestamp->year,
-				timestamp->month,
-				timestamp->day,
-				timestamp->hour,
-				timestamp->minute,
-				timestamp->second);
-	if (timestamp->fraction > 0)
-		g_string_append_printf (string, ".%lu", timestamp->fraction);
-	if (timestamp->timezone != GDA_TIMEZONE_INVALID)
-		g_string_append_printf (string, "%+02d",
-					(int) timestamp->timezone/3600);
-	g_value_take_string (dest, string->str);
-	g_string_free (string, FALSE);
+	if (timestamp) {
+		GString *string;
+		string = g_string_new ("");
+		g_string_append_printf (string, "%04u-%02u-%02u %02u:%02u:%02u",
+					timestamp->year,
+					timestamp->month,
+					timestamp->day,
+					timestamp->hour,
+					timestamp->minute,
+					timestamp->second);
+		if (timestamp->fraction > 0)
+			g_string_append_printf (string, ".%lu", timestamp->fraction);
+		if (timestamp->timezone != GDA_TIMEZONE_INVALID)
+			g_string_append_printf (string, "%+02d",
+						(int) timestamp->timezone/3600);
+		g_value_take_string (dest, string->str);
+		g_string_free (string, FALSE);
+	}
+	else
+		g_value_set_string (dest, "0000-00-00 00:00:00");
 }
 
 GType
@@ -1351,30 +1409,89 @@ gda_timestamp_valid (const GdaTimestamp *timestamp)
 {
 	g_return_val_if_fail (timestamp, FALSE);
 
-	GDate *gdate;
-
 	/* check the date part */
-	gdate = g_date_new_dmy ((GDateDay) timestamp->day, (GDateMonth) timestamp->month,
-				(GDateYear) timestamp->year);
-	if (!gdate)
+	if (! g_date_valid_dmy ((GDateDay) timestamp->day, (GDateMonth) timestamp->month,
+				(GDateYear) timestamp->year))
 		return FALSE;
-	if (! g_date_valid (gdate)) {
-		g_date_free (gdate);
-		return FALSE;
-	}
-	g_date_free (gdate);
 
 	/* check the time part */
-	if (timestamp->hour > 24 ||
-	    timestamp->minute > 59 ||
-	    timestamp->second > 59)
+	if ((timestamp->hour > 23) ||
+	    (timestamp->minute > 59) ||
+	    (timestamp->second > 59))
 		return FALSE;
-	else
-		return TRUE;
+	if ((timestamp->fraction >= 1000000) ||
+	    (timestamp->timezone <= -12 * 3600) ||
+	    (timestamp->timezone >= 12 * 3600))
+		return FALSE;
+
+	return TRUE;
 }
 
 /**
- * gda_value_new:
+ * gda_timestamp_change_timezone:
+ * @ts: a valid #GdaTimestamp
+ * @ntz: a new timezone to use, in seconds added to GMT
+ *
+ * This function is similar to gda_time_change_timezone() but operates on time stamps.
+ *
+ * Note: the resulting will always be a valid time.
+ *
+ * Since: 5.2
+ */
+void
+gda_timestamp_change_timezone (GdaTimestamp *ts, glong ntz)
+{
+	g_return_if_fail (ts);
+	g_return_if_fail (gda_timestamp_valid (ts));
+	g_return_if_fail ((ntz > - 12 * 3600) && (ntz < 12 * 3600));
+
+	if (ts->timezone == ntz)
+		return;
+
+	if (ts->timezone != GDA_TIMEZONE_INVALID) {
+		glong nsec;
+		nsec = ts->hour * 3600 + ts->minute * 60 + ts->second - ts->timezone + ntz;
+		if (nsec < 0) {
+			GDate *date;
+			date = g_date_new_dmy ((GDateDay) ts->day, (GDateMonth) ts->month, (GDateYear) ts->year);
+			g_date_subtract_days (date, 1);
+			ts->year = g_date_get_year (date);
+			ts->month = g_date_get_month (date);
+			ts->day = g_date_get_day (date);
+			g_date_free (date);
+			nsec += 86400;
+		}
+		else if (nsec >= 86400) {
+			GDate *date;
+			date = g_date_new_dmy ((GDateDay) ts->day, (GDateMonth) ts->month, (GDateYear) ts->year);
+			g_date_add_days (date, 1);
+			ts->year = g_date_get_year (date);
+			ts->month = g_date_get_month (date);
+			ts->day = g_date_get_day (date);
+			g_date_free (date);
+			nsec -= 86400;
+		}
+
+		/* hours */
+		gint n;
+		n = nsec / 3600;
+		ts->hour = (gushort) n;
+
+		/* minutes */
+		nsec -= n * 3600;
+		n = nsec / 60;
+		ts->minute = (gushort) n;
+
+		/* seconds */
+		nsec -= n * 60;
+		ts->second = (gushort) nsec;
+	}
+
+	ts->timezone = ntz;
+}
+
+/**
+ * gda_value_new: (skip)
  * @type: the new value type.
  *
  * Makes a new #GValue of type @type.
@@ -1395,7 +1512,7 @@ gda_value_new (GType type)
 }
 
 /**
- * gda_value_new_null:
+ * gda_value_new_null: (skip)
  *
  * Creates a new #GValue initiated to a #GdaNull structure with a #GDA_TYPE_NULL, to
  * represent a NULL in the database.
@@ -1409,7 +1526,7 @@ gda_value_new_null (void)
 }
 
 /**
- * gda_value_new_default:
+ * gda_value_new_default: (skip)
  * @default_val: (allow-none): the default value as a string, or %NULL
  *
  * Creates a new default value.
@@ -1428,7 +1545,7 @@ gda_value_new_default (const gchar *default_val)
 }
 
 /**
- * gda_value_new_binary:
+ * gda_value_new_binary: (skip)
  * @val: value to set for the new #GValue.
  * @size: the size of the memory pool pointer to by @val.
  *
@@ -1457,7 +1574,7 @@ gda_value_new_binary (const guchar *val, glong size)
 }
 
 /**
- * gda_value_new_blob:
+ * gda_value_new_blob: (skip)
  * @val: value to set for the new #GValue.
  * @size: the size of the memory pool pointer to by @val.
  *
@@ -1489,7 +1606,7 @@ gda_value_new_blob (const guchar *val, glong size)
 }
 
 /**
- * gda_value_new_blob_from_file:
+ * gda_value_new_blob_from_file: (skip)
  * @filename: name of the file to manipulate
  *
  * Makes a new #GValue of type #GDA_TYPE_BLOB interfacing with the contents of the file
@@ -1506,7 +1623,7 @@ gda_value_new_blob_from_file (const gchar *filename)
 	GdaBlob *blob;
 
 	blob = g_new0 (GdaBlob, 1);
-	blob->op = gda_dir_blob_op_new (filename);
+	blob->op = _gda_dir_blob_op_new (filename);
 
         value = g_new0 (GValue, 1);
 	g_value_init (value, GDA_TYPE_BLOB);
@@ -1515,36 +1632,90 @@ gda_value_new_blob_from_file (const gchar *filename)
         return value;
 }
 
+/*
+ * Warning: modifies @gmttm and loctm
+ *
+ * Returns: the offset, or G_MAXLONG in case of error
+ */
+static glong
+compute_tz_offset (struct tm *gmttm, struct tm *loctm)
+{
+	time_t lt, gt;
+	if (! gmttm || !loctm)
+		return G_MAXLONG;
+
+	gmttm->tm_isdst = 0;
+	loctm->tm_isdst = 0;
+
+	lt = mktime (loctm);
+	if (lt == -1)
+		return G_MAXLONG;
+	gt = mktime (gmttm);
+	if (gt == -1)
+		return G_MAXLONG;
+
+	glong off;
+	off = lt - gt;
+	if ((off >= 24 * 3600) || (off <= - 24 * 3600))
+		return G_MAXLONG;
+	else
+		return off;
+}
+
 /**
- * gda_value_new_timestamp_from_timet:
+ * gda_value_new_timestamp_from_timet: (skip)
  * @val: value to set for the new #GValue.
  *
  * Makes a new #GValue of type #GDA_TYPE_TIMESTAMP with value @val
- * (of type time_t).
+ * (of type time_t). The returned timestamp's value is relative to the current
+ * timezone (i.e. is localtime).
  *
- * Returns: (transfer full): the newly created #GValue.
+ * For example, to get a time stamp representing the current date and time, use:
+ *
+ * <code>
+ * ts = gda_value_new_timestamp_from_timet (time (NULL));
+ * </code>
+ *
+ * Returns: (transfer full): the newly created #GValue, or %NULL in case of error
  *
  * Free-function: gda_value_free
  */
 GValue *
 gda_value_new_timestamp_from_timet (time_t val)
 {
-	GValue *value;
+	GValue *value = NULL;
+	struct tm *ltm = NULL;
+	glong tz = 0;
 
-	struct tm *ltm;
-
-        value = g_new0 (GValue, 1);
 #ifdef HAVE_LOCALTIME_R
-	struct tm tmpstm;
-	ltm = localtime_r ((const time_t *) &val, &tmpstm);
-#elif HAVE_LOCALTIME_S
-	struct tm tmpstm;
-	if (localtime_s (&tmpstm, (const time_t *) &val) == 0)
-		ltm = &tmpstm;
-	else
+	struct tm gmttm, loctm;
+	tzset ();
+	ltm = localtime_r ((const time_t *) &val, &loctm);
+	tz = compute_tz_offset (gmtime_r ((const time_t *) &val, &gmttm), &loctm);
+	if (tz == G_MAXLONG)
 		ltm = NULL;
+#elif HAVE_LOCALTIME_S
+	struct tm gmttm, loctm;
+	if ((localtime_s (&loctm, (const time_t *) &val) == 0) &&
+	    (gmtime_s (&gmttm, (const time_t *) &val) == 0)) {
+		tz = compute_tz_offset (&gmttm, &loctm);
+		if (tz != G_MAXLONG)
+			ltm = &loctm;
+	}
 #else
-	ltm = localtime ((const time_t *) &val);
+	struct tm gmttm, loctm;
+	ltm = gmtime ((const time_t *) &val);
+	if (ltm) {
+		gmttm = *ltm;
+		ltm = localtime ((const time_t *) &val);
+		if (ltm) {
+			loctm = *ltm;
+			tz = compute_tz_offset (&gmttm, &loctm);
+			if (tz == G_MAXLONG)
+				ltm = NULL;
+		}
+	}
+	
 #endif
 
         if (ltm) {
@@ -1556,7 +1727,9 @@ gda_value_new_timestamp_from_timet (time_t val)
                 tstamp.minute = ltm->tm_min;
                 tstamp.second = ltm->tm_sec;
                 tstamp.fraction = 0;
-                tstamp.timezone = GDA_TIMEZONE_INVALID;
+                tstamp.timezone = tz;
+
+		value = g_new0 (GValue, 1);
                 gda_value_set_timestamp (value, (const GdaTimestamp *) &tstamp);
         }
 
@@ -1564,7 +1737,7 @@ gda_value_new_timestamp_from_timet (time_t val)
 }
 
 /**
- * gda_value_new_from_string:
+ * gda_value_new_from_string: (skip)
  * @as_string: stringified representation of the value.
  * @type: the new value type.
  *
@@ -1596,7 +1769,7 @@ gda_value_new_from_string (const gchar *as_string, GType type)
 }
 
 /**
- * gda_value_new_from_xml:
+ * gda_value_new_from_xml: (skip)
  * @node: an XML node representing the value.
  *
  * Creates a GValue from an XML representation of it. That XML
@@ -1639,7 +1812,7 @@ gda_value_new_from_xml (const xmlNodePtr node)
 }
 
 /**
- * gda_value_free:
+ * gda_value_free: (skip)
  * @value: (transfer full) (allow-none): the resource to free (or %NULL)
  *
  * Deallocates all memory associated to a #GValue.
@@ -1654,7 +1827,7 @@ gda_value_free (GValue *value)
 }
 
 /**
- * gda_value_reset_with_type:
+ * gda_value_reset_with_type: (skip)
  * @value: the #GValue to be reseted
  * @type:  the #GType to set to
  *
@@ -1679,7 +1852,7 @@ gda_value_reset_with_type (GValue *value, GType type)
 
 
 /**
- * gda_value_is_null:
+ * gda_value_is_null: (skip)
  * @value: value to test.
  *
  * Tests if a given @value is of type #GDA_TYPE_NULL.
@@ -1694,7 +1867,7 @@ gda_value_is_null (const GValue *value)
 }
 
 /**
- * gda_value_is_number:
+ * gda_value_is_number: (skip)
  * @value: a #GValue.
  *
  * Gets whether the value stored in the given #GValue is of numeric type or not.
@@ -1717,7 +1890,7 @@ gda_value_is_number (const GValue *value)
 }
 
 /**
- * gda_value_copy:
+ * gda_value_copy: (skip)
  * @value: value to get a copy from.
  *
  * Creates a new #GValue from an existing one.
@@ -1744,7 +1917,7 @@ gda_value_copy (const GValue *value)
 }
 
 /**
- * gda_value_get_binary:
+ * gda_value_get_binary: (skip)
  * @value: a #GValue whose value we want to get.
  *
  * Returns: (transfer none): the value stored in @value.
@@ -1764,7 +1937,7 @@ gda_value_get_binary (const GValue *value)
 
 
 /**
- * gda_value_set_binary:
+ * gda_value_set_binary: (skip)
  * @value: a #GValue that will store @val.
  * @binary: a #GdaBinary structure with the data and its size to be stored in @value.
  *
@@ -1786,7 +1959,7 @@ gda_value_set_binary (GValue *value, const GdaBinary *binary)
 }
 
 /**
- * gda_value_take_binary:
+ * gda_value_take_binary: (skip)
  * @value: a #GValue that will store @val.
  * @binary: (transfer full): a #GdaBinary structure with the data and its size to be stored in @value.
  *
@@ -1805,7 +1978,7 @@ gda_value_take_binary (GValue *value, GdaBinary *binary)
 }
 
 /**
- * gda_value_set_blob:
+ * gda_value_set_blob: (skip)
  * @value: a #GValue that will store @val.
  * @blob: a #GdaBlob structure with the data and its size to be stored in @value.
  *
@@ -1823,7 +1996,7 @@ gda_value_set_blob (GValue *value, const GdaBlob *blob)
 }
 
 /**
- * gda_value_get_blob:
+ * gda_value_get_blob: (skip)
  * @value: a #GValue whose value we want to get.
  *
  * Returns: (transfer none): the value stored in @value.
@@ -1842,7 +2015,7 @@ gda_value_get_blob (const GValue *value)
 }
 
 /**
- * gda_value_take_blob:
+ * gda_value_take_blob: (skip)
  * @value: a #GValue that will store @val.
  * @blob: (transfer full): a #GdaBlob structure with the data and its size to be stored in @value.
  *
@@ -1861,7 +2034,7 @@ gda_value_take_blob (GValue *value, GdaBlob *blob)
 }
 
 /**
- * gda_value_get_geometric_point:
+ * gda_value_get_geometric_point: (skip)
  * @value: a #GValue whose value we want to get.
  *
  * Returns: (transfer none): the value stored in @value.
@@ -1875,7 +2048,7 @@ gda_value_get_geometric_point (const GValue *value)
 }
 
 /**
- * gda_value_set_geometric_point:
+ * gda_value_set_geometric_point: (skip)
  * @value: a #GValue that will store @val.
  * @val: value to be stored in @value.
  *
@@ -1893,7 +2066,7 @@ gda_value_set_geometric_point (GValue *value, const GdaGeometricPoint *val)
 }
 
 /**
- * gda_value_set_null
+ * gda_value_set_null: (skip)
  * @value: a #GValue that will store a value of type #GDA_TYPE_NULL.
  *
  * Sets the type of @value to #GDA_TYPE_NULL.
@@ -1906,7 +2079,7 @@ gda_value_set_null (GValue *value)
 }
 
 /**
- * gda_value_get_numeric
+ * gda_value_get_numeric: (skip)
  * @value: a #GValue whose value we want to get.
  *
  * Returns: (transfer none): the value stored in @value.
@@ -1920,7 +2093,7 @@ gda_value_get_numeric (const GValue *value)
 }
 
 /**
- * gda_value_set_numeric:
+ * gda_value_set_numeric: (skip)
  * @value: a #GValue that will store @val.
  * @val: value to be stored in @value.
  *
@@ -1938,7 +2111,7 @@ gda_value_set_numeric (GValue *value, const GdaNumeric *val)
 }
 
 /**
- * gda_value_get_short:
+ * gda_value_get_short: (skip)
  * @value: a #GValue whose value we want to get.
  *
  * Returns: the value stored in @value.
@@ -1952,7 +2125,7 @@ gda_value_get_short (const GValue *value)
 }
 
 /**
- * gda_value_set_short:
+ * gda_value_set_short: (skip)
  * @value: a #GValue that will store @val.
  * @val: value to be stored in @value.
  *
@@ -1969,7 +2142,7 @@ gda_value_set_short (GValue *value, gshort val)
 }
 
 /**
- * gda_value_get_ushort:
+ * gda_value_get_ushort: (skip)
  * @value: a #GValue whose value we want to get.
  *
  * Returns: the value stored in @value.
@@ -1983,7 +2156,7 @@ gda_value_get_ushort (const GValue *value)
 }
 
 /**
- * gda_value_set_ushort:
+ * gda_value_set_ushort: (skip)
  * @value: a #GValue that will store @val.
  * @val: value to be stored in @value.
  *
@@ -2001,7 +2174,7 @@ gda_value_set_ushort (GValue *value, gushort val)
 
 
 /**
- * gda_value_get_time:
+ * gda_value_get_time: (skip)
  * @value: a #GValue whose value we want to get.
  *
  * Returns: (transfer none): the value stored in @value.
@@ -2015,7 +2188,7 @@ gda_value_get_time (const GValue *value)
 }
 
 /**
- * gda_value_set_time:
+ * gda_value_set_time: (skip)
  * @value: a #GValue that will store @val.
  * @val: value to be stored in @value.
  *
@@ -2033,7 +2206,7 @@ gda_value_set_time (GValue *value, const GdaTime *val)
 }
 
 /**
- * gda_value_get_timestamp:
+ * gda_value_get_timestamp: (skip)
  * @value: a #GValue whose value we want to get.
  *
  * Returns: (transfer none): the value stored in @value.
@@ -2047,7 +2220,7 @@ gda_value_get_timestamp (const GValue *value)
 }
 
 /**
- * gda_value_set_timestamp:
+ * gda_value_set_timestamp: (skip)
  * @value: a #GValue that will store @val.
  * @val: value to be stored in @value.
  *
@@ -2065,7 +2238,7 @@ gda_value_set_timestamp (GValue *value, const GdaTimestamp *val)
 }
 
 /**
- * gda_value_set_from_string:
+ * gda_value_set_from_string: (skip)
  * @value: a #GValue that will store @val.
  * @as_string: the stringified representation of the value.
  * @type: the type of the value
@@ -2103,7 +2276,7 @@ gda_value_set_from_string (GValue *value,
 }
 
 /**
- * gda_value_set_from_value:
+ * gda_value_set_from_value: (skip)
  * @value: a #GValue.
  * @from: the value to copy from.
  *
@@ -2149,7 +2322,7 @@ gda_value_set_from_value (GValue *value, const GValue *from)
  * #GdaDataHandler objects). Using this function should be limited to debugging and values serialization
  * purposes.
  *
- * Dates are converted in a YYYY-MM-DD format.
+ * Output is in the "C" locale for numbers, and dates are converted in a YYYY-MM-DD format.
  *
  * Returns: (transfer full): a new string, or %NULL if the conversion cannot be done. Free the value with a g_free() when you've finished using it.
  */
@@ -2158,7 +2331,37 @@ gda_value_stringify (const GValue *value)
 {
 	if (!value)
 		return g_strdup ("NULL");
-	if (g_value_type_transformable (G_VALUE_TYPE (value), G_TYPE_STRING)) {
+
+	GType type = G_VALUE_TYPE (value);
+	if (type == G_TYPE_FLOAT) {
+		char buffer[G_ASCII_DTOSTR_BUF_SIZE];
+		g_ascii_formatd (buffer, sizeof (buffer), "%f", g_value_get_float (value));
+		return g_strdup (buffer);
+	}
+	else if (type == G_TYPE_DOUBLE) {
+		char buffer[G_ASCII_DTOSTR_BUF_SIZE];
+		g_ascii_formatd (buffer, sizeof (buffer), "%f", g_value_get_double (value));
+		return g_strdup (buffer);
+	}
+	else if (type == GDA_TYPE_NUMERIC)
+		return gda_numeric_get_string (gda_value_get_numeric (value));
+	else if (type == G_TYPE_DATE) {
+		GDate *date;
+		date = (GDate *) g_value_get_boxed (value);
+		if (date) {
+			if (g_date_valid (date))
+				return g_strdup_printf ("%04u-%02u-%02u",
+							g_date_get_year (date),
+							g_date_get_month (date),
+							g_date_get_day (date));
+			else
+				return g_strdup_printf ("%04u-%02u-%02u",
+							date->year, date->month, date->day);
+		}
+		else
+			return g_strdup ("0000-00-00");
+	}
+	else if (g_value_type_transformable (G_VALUE_TYPE (value), G_TYPE_STRING)) {
 		GValue *string;
 		gchar *str;
 
@@ -2168,27 +2371,13 @@ gda_value_stringify (const GValue *value)
 		gda_value_free (string);
 		return str;
 	}
-	else {
-		GType type = G_VALUE_TYPE (value);
-		if (type == G_TYPE_DATE) {
-			GDate *date;
-			date = (GDate *) g_value_get_boxed (value);
-			if (date) {
-				if (g_date_valid (date))
-					return g_strdup_printf ("%04u-%02u-%02u",
-								g_date_get_year (date),
-								g_date_get_month (date),
-								g_date_get_day (date));
-				else
-					return g_strdup_printf ("%04u-%02u-%02u",
-								date->year, date->month, date->day);
-			}
-			else
-				return g_strdup ("0000-00-00");
-		}
-		else
-			return g_strdup ("");
+	else if (G_TYPE_IS_OBJECT (type)) {
+		GObject *obj;
+		obj = g_value_get_object (value);
+		return g_strdup_printf ("%p (%s)", obj, G_OBJECT_TYPE_NAME (obj));
 	}
+	else
+		return g_strdup ("");
 }
 
 /**
@@ -2495,12 +2684,8 @@ gda_value_compare (const GValue *value1, const GValue *value2)
 			else
 				retval = 1;
 		}
-		else {
-			if (num2->number)
-				retval = -1;
-			else
-				retval = 0;
-		}
+		else
+			retval = -1;
 		return retval;
 	}
 
@@ -2583,13 +2768,8 @@ gda_value_compare (const GValue *value1, const GValue *value2)
 	}
 
 	else if (type == G_TYPE_CHAR) {
-#if GLIB_CHECK_VERSION(2,31,7)
 		gint8 c1 = g_value_get_schar (value1);
 		gint8 c2 = g_value_get_schar (value2);
-#else
-		gchar c1 = g_value_get_char (value1);
-		gchar c2 = g_value_get_char (value2);
-#endif
 		return (c1 > c2) ? 1 : ((c1 == c2) ? 0 : -1);
 	}
 
@@ -2904,7 +3084,7 @@ gda_string_to_binary (const gchar *str)
 	}
 
 	total = strlen (str);
-	retval = g_new0 (gchar, total + 1);
+	retval = g_new0 (guchar, total + 1);
 	sptr = (guchar*) str;
 	rptr = retval;
 
