@@ -1,14 +1,15 @@
 /*
  * Copyright (C) 2001 - 2003 Rodrigo Moya <rodrigo@gnome-db.org>
  * Copyright (C) 2002 - 2003 Gonzalo Paniagua Javier <gonzalo@gnome-db.org>
- * Copyright (C) 2002 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2002 - 2013 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2003 Akira TAGOH <tagoh@gnome-db.org>
  * Copyright (C) 2003 Danilo Schoeneberg <dschoene@src.gnome.org>
  * Copyright (C) 2003 Laurent Sansonetti <laurent@datarescue.be>
- * Copyright (C) 2004 - 2007 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2004 - 2011 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2004 Paisa  Seeluangsawat <paisa@users.sf.net>
  * Copyright (C) 2008 Przemysław Grzegorczyk <pgrzegorczyk@gmail.com>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
+ * Copyright (C) 2011 Daniel Espinosa <despinosa@src.gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -78,20 +79,6 @@ typedef struct {
 typedef struct _GdaNumeric GdaNumeric;
 # ifdef GSEAL_ENABLE
 # else
-/**
- * GdaNumeric:
- * @number: a string representing a number
- * @precision: precision to use when @number is converted (not implemented jet)
- * @width: (not implemented jet)
- *
- * Holds numbers represented as strings.
- *
- * This struct must be considered as opaque. Any access to its members must use its
- * accessors added since version 5.0.2.
- *
- * Set value func: gda_value_set_numeric
- * Get value func: gda_value_get_numeric
- */
 struct _GdaNumeric {
 	gchar*   GSEAL(number);
 	glong    GSEAL(precision);
@@ -104,30 +91,34 @@ struct _GdaNumeric {
 
 /**
  * GdaTime:
- * @hour: 
- * @minute: 
- * @second: 
- * @fraction: 
- * @timezone: 
+ * @hour: hour representation of the time, as a number between 0 and 23
+ * @minute: minute representation of the time, as a number between 0 and 59
+ * @second: second representation of the time, as a number between 0 and 59
+ * @fraction: fractionnal part of the seconds, in millionth' of second
+ * @timezone: number of seconds added to the GMT timezone
+ *
+ * Represents a time information.
  */
 typedef struct {
 	gushort hour;
 	gushort minute;
 	gushort second;
 	gulong  fraction;
-	glong   timezone;	/* # of seconds to the east UTC */
+	glong   timezone;
 } GdaTime;
 
 /**
  * GdaTimestamp:
- * @year: representation of the date
- * @month: month representation of the date, as a number between 1 and 12
- * @day: day representation of the date, as a number between 1 and 31
- * @hour: 
- * @minute: 
- * @second: 
- * @fraction: 
- * @timezone:
+ * @year: year representation of the time stamp
+ * @month: month representation of the time stamp, as a number between 1 and 12
+ * @day: day representation of the time stamp, as a number between 1 and 31
+ * @hour: hour representation of the time stamp, as a number between 0 and 23
+ * @minute: minute representation of the time stamp, as a number between 0 and 59
+ * @second: second representation of the time stamp, as a number between 0 and 59
+ * @fraction: fractionnal part of the seconds, in millionth' of second
+ * @timezone: number of seconds added to the GMT timezone
+ *
+ * Represents an instant (a time stamp)
  */
 typedef struct {
 	gshort  year;
@@ -137,7 +128,7 @@ typedef struct {
 	gushort minute;
 	gushort second;
 	gulong  fraction;
-	glong   timezone;	/* # of seconds to the east UTC */
+	glong   timezone;
 } GdaTimestamp;
 
 /**
@@ -151,7 +142,7 @@ typedef struct {
 } GdaBinary;
 
 /**
- * GdaBlob
+ * GdaBlob:
  * @data: data buffer, as a #GdaBinary
  * @op: (allow-none): a pointer to a #GdaBlopOp, or %NULL
  *
@@ -272,24 +263,25 @@ GdaNumeric*                       gda_numeric_new (void);
 GdaNumeric*                       gda_numeric_copy (GdaNumeric *src);
 void                              gda_numeric_set_from_string (GdaNumeric *numeric, const gchar* str);
 void                              gda_numeric_set_double (GdaNumeric *numeric, gdouble number);
-gdouble                           gda_numeric_get_double (GdaNumeric *numeric);
+gdouble                           gda_numeric_get_double (const GdaNumeric *numeric);
 void                              gda_numeric_set_precision (GdaNumeric *numeric, glong precision);
-glong                             gda_numeric_get_precision (GdaNumeric *numeric);
+glong                             gda_numeric_get_precision (const GdaNumeric *numeric);
 void                              gda_numeric_set_width (GdaNumeric *numeric, glong width);
-glong                             gda_numeric_get_width (GdaNumeric *numeric);
-gchar*                            gda_numeric_get_string (GdaNumeric *numeric);
+glong                             gda_numeric_get_width (const GdaNumeric *numeric);
+gchar*                            gda_numeric_get_string (const GdaNumeric *numeric);
 void                              gda_numeric_free (GdaNumeric *numeric);
 
 GType                             gda_time_get_type (void) G_GNUC_CONST;
 gpointer                          gda_time_copy (gpointer boxed);
 void                              gda_time_free (gpointer boxed);
 gboolean                          gda_time_valid (const GdaTime *time);
-
+void                              gda_time_change_timezone (GdaTime *time, glong ntz);
 
 GType                             gda_timestamp_get_type (void) G_GNUC_CONST;
 gpointer                          gda_timestamp_copy (gpointer boxed);
 void                              gda_timestamp_free (gpointer boxed);
 gboolean                          gda_timestamp_valid (const GdaTimestamp *timestamp);
+void                              gda_timestamp_change_timezone (GdaTimestamp *ts, glong ntz);
 
 
 GType                             gda_geometricpoint_get_type (void) G_GNUC_CONST;
