@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2008 - 2009 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2008 - 2010 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
  *
@@ -55,10 +55,10 @@ gda_sql_error_quark (void)
 GdaSqlStatementContentsInfo *
 gda_sql_statement_get_contents_infos  (GdaSqlStatementType type)
 {
-	static GStaticMutex mutex = G_STATIC_MUTEX_INIT;
+	static GMutex mutex;
 	static GdaSqlStatementContentsInfo **contents = NULL;
 
-	g_static_mutex_lock (&mutex);
+	g_mutex_lock (&mutex);
 	if (!contents) {
 		contents = g_new0 (GdaSqlStatementContentsInfo *, GDA_SQL_STATEMENT_NONE);
 
@@ -75,7 +75,7 @@ gda_sql_statement_get_contents_infos  (GdaSqlStatementType type)
 		contents [GDA_SQL_STATEMENT_ROLLBACK_SAVEPOINT] = _gda_sql_statement_rollback_savepoint_get_infos ();
 		contents [GDA_SQL_STATEMENT_DELETE_SAVEPOINT] = _gda_sql_statement_delete_savepoint_get_infos ();
 	}
-	g_static_mutex_unlock (&mutex);
+	g_mutex_unlock (&mutex);
 
 	return contents[type];
 }
@@ -198,10 +198,8 @@ gda_sql_statement_type_to_string (GdaSqlStatementType type)
 {
 	GdaSqlStatementContentsInfo *infos;
 	infos = gda_sql_statement_get_contents_infos (type);
-	if (!infos) {
+	if (!infos)
 		return "NONE";
-		TO_IMPLEMENT;
-	}
 	else
 		return infos->name;
 }
@@ -1052,7 +1050,9 @@ gda_sql_any_part_check_structure (GdaSqlAnyPart *node, GError **error)
 		case GDA_SQL_OPERATOR_TYPE_EQ:
 		case GDA_SQL_OPERATOR_TYPE_IS:
 		case GDA_SQL_OPERATOR_TYPE_LIKE:
+		case GDA_SQL_OPERATOR_TYPE_NOTLIKE:
 		case GDA_SQL_OPERATOR_TYPE_ILIKE:
+		case GDA_SQL_OPERATOR_TYPE_NOTILIKE:
 		case GDA_SQL_OPERATOR_TYPE_GT:
 		case GDA_SQL_OPERATOR_TYPE_LT:
 		case GDA_SQL_OPERATOR_TYPE_GEQ:
