@@ -1,4 +1,5 @@
 /*
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -246,8 +247,12 @@ visibility_notify_event (GtkWidget *text_view, G_GNUC_UNUSED GdkEventVisibility
 			 ClassProperties *cprop)
 {
 	gint wx, wy, bx, by;
-	
-	gdk_window_get_pointer (gtk_widget_get_window (text_view), &wx, &wy, NULL);
+	GdkDeviceManager *manager;
+	GdkDevice *pointer;
+
+	manager = gdk_display_get_device_manager (gtk_widget_get_display (text_view));
+	pointer = gdk_device_manager_get_client_pointer (manager);
+	gdk_window_get_device_position (gtk_widget_get_window (text_view), pointer, &wx, &wy, NULL);
 	
 	gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (text_view), 
 					       GTK_TEXT_WINDOW_WIDGET,
@@ -272,8 +277,6 @@ motion_notify_event (GtkWidget *text_view, GdkEventMotion *event, ClassPropertie
 	
 	set_cursor_if_appropriate (GTK_TEXT_VIEW (text_view), x, y, cprop);
 
-	gdk_window_get_pointer (gtk_widget_get_window (text_view), NULL, NULL, NULL);
-
 	return FALSE;
 }
 
