@@ -93,7 +93,7 @@ mgr_ldap_classes_get_type (void)
         static GType type = 0;
 
         if (G_UNLIKELY (type == 0)) {
-                static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+                static GMutex registering;
                 static const GTypeInfo info = {
                         sizeof (MgrLdapClassesClass),
                         (GBaseInitFunc) NULL,
@@ -107,10 +107,10 @@ mgr_ldap_classes_get_type (void)
 			0
                 };
 
-                g_static_mutex_lock (&registering);
+                g_mutex_lock (&registering);
                 if (type == 0)
                         type = g_type_register_static (GDA_TYPE_TREE_MANAGER, "_MgrLdapClasses", &info, 0);
-                g_static_mutex_unlock (&registering);
+                g_mutex_unlock (&registering);
         }
         return type;
 }
